@@ -25,12 +25,13 @@ def print_fancy_summary(output: ProblemOutput) -> None:
     )
 
     for test in output.tests:
-        if not test.hidden:
-            rprint(
-                Panel(
-                    test.output or "",
-                    title=("" if test.is_correct() else "[bright_red]") + test.name,
-                    subtitle=f"{test.score}/{test.max_score}",
-                    **RICH_PANEL_OPTS,  # type: ignore
-                )
+        rprint(
+            Panel(
+                test.rich_output,
+                title=("" if test.is_correct() else "[bright_red]")
+                + ("(HIDDEN) " if test.hidden else "")
+                + test.name,
+                subtitle=f"{test.score}/{test.max_score}",
+                **RICH_PANEL_OPTS,  # type: ignore
             )
+        )
